# Aerolyzer

[![license](https://img.shields.io/github/license/Aerolyzer/Aerolyzer.svg?maxAge=2592000?style=plastic)](http://www.apache.org/licenses/LICENSE-2.0)
[![Build Status](https://travis-ci.org/Aerolyzer/Aerolyzer.svg?branch=master)](https://travis-ci.org/Aerolyzer/Aerolyzer)
[![Coverage Status](https://coveralls.io/repos/github/Aerolyzer/Aerolyzer/badge.svg?branch=master)](https://coveralls.io/github/Aerolyzer/Aerolyzer?branch=master)


Oregon State University 2016 - 2017 Computer Science Capstone Project

Group Members: E. Reilly Collins, Jesse Hanson, Sophia Liu
<br>Project Managers: Dr. Kim Whitehall, Dr. Lewis McGibbney
<br>Class lecturer: Dr. Kevin McGrath

## Introduction and motivation
Millions of digital images are taken on mobile phones daily, some of which contain outdoor scenes. Combining this volume
of mobile users’ landscape images with camera metadata provides an untapped resource for inferring atmospheric composition in real-time globally. Such an application would provide an inexpensive method to monitor the movement of larger aerosols through the atmosphere from the surface, and augement the existing satellite and point instrument sources on the ground. 
<br>The purpose of this project is to develop an application that supports the ability to infer atmospheric composition from these digital outdoor images. To accomplish this, we will combine image processing of the photographs, phone metadata, meteorological information from external sources including satellite data and station data and the science of scattering of visible wavelengths of light into a suite of algorithms. Our ultimate goal is to produce near-real time monitoring of atmospheric conditions within a mobile app. 
The users of the mobile application will be able to monitor the air composition from their and other user contributions. <br> How cool would it be to have a general idea of the atmospheric composition ahead of travelling *#allergiesmuch* or a hint that beautiful sunsets maybe coming your way soon *#beautifulworld*!

## Project Summary
**Aerolyzer** provides a suite of algorithms (written mostly in Python) to process digital images, identify outdoor scenes, and infer atmospheric composition based on the scattering of the visible wavelength. More information on Aerolyze can be found in the [docs] (https://github.com/Aerolyzer/Aerolyzer/tree/master/docs) directory.

## Community and Development
### Mailing list
To become involved or if you require help using the project request to join our project [Google Group](https://groups.google.com/forum/#!forum/aerolyzer)

### Issue tracker
If you have issue using Aerolyzer, or suggestions for improvements please log a ticket in our [issue tracker](https://github.com/Aerolyzer/Aerolyzer/issues)

### License
**Aerolyzer** is licensed under the [Apache License v2.0](http://www.apache.org/licenses/LICENSE-2.0), a copy of which is shipped with this source code.
